common

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 4, 2024 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MessageSerializer

type MessageSerializer interface {
	MessageToProduceMessage(value string) string
}

MessageSerializer is an interface that defines the behavior of a message serializer. It is used to convert a message to a message that can be produced to a message broker.

type Topic

type Topic struct {
	Name      string
	Partition int32
}

Topic is a struct that represents a topic in a message broker. It is treated as a just "Value Object" and should not contain any business logic.

Jump to