Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MessageSerializer ¶
MessageSerializer is an interface that defines the behavior of a message serializer. It is used to convert a message to a message that can be produced to a message broker.
Click to show internal directories.
Click to hide internal directories.